"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TooltipMenu = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _TooltipMenuItem = require("./TooltipMenuItem");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const TooltipMenu = _ref => {
  let {
    children,
    items,
    style,
    overlayStyle,
    widthType,
    labelContainerStyle,
    labelStyle,
    modalButtonStyle,
    onRequestClose,
    trianglePosition
  } = _ref;
  const {
    width: windowWidth,
    height: windowHeight
  } = (0, _reactNative.useWindowDimensions)();
  const buttonRef = /*#__PURE__*/(0, _react.createRef)();
  const [isModalOpen, setModalOpen] = (0, _react.useState)(false);
  const [componentPosition, setComponentPosition] = (0, _react.useState)();
  const opacity = (0, _react.useMemo)(() => new _reactNative.Animated.Value(0), []);

  const toggleModal = () => {
    setModalOpen(!isModalOpen);
  };

  const openModal = () => {
    _reactNative.Animated.timing(opacity, {
      toValue: 1,
      duration: 300,
      useNativeDriver: true
    }).start(toggleModal);
  };

  const calculateItemWith = () => {
    switch (widthType) {
      case 'half':
        return windowWidth / 2;

      case 'full':
        return windowWidth;

      default:
        return componentPosition === null || componentPosition === void 0 ? void 0 : componentPosition.width;
    }
  };

  const hideModal = () => {
    _reactNative.Animated.timing(opacity, {
      toValue: 0,
      duration: 300,
      useNativeDriver: true
    }).start(toggleModal);
  };

  const handleClick = onClickItem => {
    const method = isModalOpen ? hideModal : openModal;
    method();
    onClickItem();
  };

  const calculatePosition = event => {
    const width = event.nativeEvent.layout.width;
    const height = event.nativeEvent.layout.height;

    if (!componentPosition && buttonRef.current) {
      buttonRef.current.measureInWindow((x, y) => {
        setComponentPosition({
          x,
          y,
          width,
          height
        });
      });
    }
  };

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: style,
    ref: buttonRef
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: openModal,
    onLayout: event => calculatePosition(event)
  }, children)), /*#__PURE__*/_react.default.createElement(_reactNative.Modal, {
    visible: isModalOpen,
    transparent: true,
    onRequestClose: onRequestClose
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.overlay, overlayStyle]
  }), /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 1,
    style: [{
      flex: 1
    }, modalButtonStyle],
    onPress: hideModal
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.component, componentPosition && {
      top: componentPosition.y,
      left: componentPosition.x
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: isModalOpen ? hideModal : openModal
  }, children)), /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [{
      minWidth: calculateItemWith()
    }, styles.tooltipContainer, componentPosition && {
      bottom: windowHeight - componentPosition.y + _reactNative.Platform.select({
        default: 10,
        android: -15
      }),
      left: componentPosition.x
    }, {
      opacity
    }]
  }, items.map((item, index) => {
    const classes = [];

    if (labelContainerStyle) {
      classes.push(labelContainerStyle);
    }

    if (index !== items.length - 1) {
      classes.push(styles.tooltipMargin);
    }

    return /*#__PURE__*/_react.default.createElement(_TooltipMenuItem.TooltipMenuItem, {
      key: index,
      label: item.label,
      onPress: () => handleClick(item.onPress),
      containerStyle: classes,
      labelStyle: labelStyle,
      testID: item.testID
    });
  })), /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.triangle, {
      opacity
    }, componentPosition && {
      top: componentPosition.y - 10
    }, componentPosition && trianglePosition === 'center' && {
      left: componentPosition.x + componentPosition.width / 2 - 10
    }, componentPosition && trianglePosition === 'left' && {
      left: componentPosition.x + 20
    }, componentPosition && trianglePosition === 'right' && {
      left: componentPosition.x + componentPosition.width - 40
    }]
  }))));
};

exports.TooltipMenu = TooltipMenu;
TooltipMenu.defaultProps = {
  widthType: 'auto',
  onRequestClose: () => {},
  trianglePosition: 'center'
};

const styles = _reactNative.StyleSheet.create({
  overlay: { ..._reactNative.StyleSheet.absoluteFillObject,
    backgroundColor: 'rgba(0,0,0,0.5)'
  },
  tooltipMargin: {
    borderBottomWidth: 1,
    borderBottomColor: '#E1E1E1'
  },
  component: {
    position: 'absolute'
  },
  tooltipContainer: {
    backgroundColor: 'white',
    borderRadius: 10,
    position: 'absolute'
  },
  triangle: {
    position: 'absolute',
    width: 10,
    height: 10,
    backgroundColor: 'transparent',
    borderStyle: 'solid',
    borderTopWidth: 10,
    borderRightWidth: 10,
    borderBottomWidth: 0,
    borderLeftWidth: 10,
    borderTopColor: 'white',
    borderRightColor: 'transparent',
    borderBottomColor: 'transparent',
    borderLeftColor: 'transparent'
  }
});
//# sourceMappingURL=TooltipMenu.js.map